<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :ajaxFun="ajaxFun"
        ref="operationTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
    </basic-container>
  </div>
</template>

<script>
import { fetchList, delObj, getLaborClassNo } from '@/api/technology/operation'
import ttable from '@/views/common/ztt-table.vue'
import TableForm from './operation-form'
import { remote } from '@/api/admin/dict'
import { mapGetters } from 'vuex'
export default {
  data() {
    return {
      ajaxFun: fetchList,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: true,
        url: '/mes/operation/excel/upload'
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 工序编号
          {
            minWidth: '140',
            prop: 'operationNo',
            label: '工序编号',
            sort: true,
            isTrue: true,
            formatter: (row, column, cellValue) => {
              return cellValue
            },
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          },
          // 工序名称
          {
            minWidth: '120',
            prop: 'name',
            label: '工序名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 零件族
          {
            minWidth: '120',
            prop: 'partFamilyName',
            label: '零件族',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 工作中心
          {
            minWidth: '120',
            prop: 'workCenter',
            label: '工作中心',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.formatWorkCenterType,
            optList: () => {
              return this.workCenterTypeOptions
            }
          },
          // 机器运转因素
          {
            minWidth: '120',
            prop: 'machRunFactor',
            label: '机器运转因素',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 机器设置时间
          {
            minWidth: '120',
            prop: 'machSetupTime',
            label: '机器设置时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 人工类别
          {
            minWidth: '120',
            prop: 'laborClassNo',
            label: '人工类别',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.formatLaborClassNo,
            optList: () => {
              return this.getLaborClassNoList()
            }
          },
          // 劳力运转因素
          {
            minWidth: '120',
            prop: 'laborRunFactor',
            label: '劳力运转因素',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 劳力设置时间
          {
            minWidth: '120',
            prop: 'laborSetupTime',
            label: '劳力设置时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 因素单位
          {
            minWidth: '120',
            prop: 'runTimeCodeDb',
            label: '因素单位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.formatRunTimeCodeDbType,
            optList: () => {
              return this.runTimeCodeDbTypeOptions
            }
          },
          // 班组人员
          {
            minWidth: '120',
            prop: 'crewSize',
            label: '班组人员',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'outsideOpItem',
            label: '外部工序项目',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.formatOutsideOpItem,
            optList: () => {
              return this.outsideOpItemOptions
            }
          },
          // 备注
          {
            minWidth: '120',
            prop: 'remark',
            label: '备注',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 更新时间
          {
            minWidth: '200',
            prop: 'updateTime',
            label: '更新时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          }
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addOrUpdateHandle
          }
        ],
        operator: [
          {
            text: '删除',
            type: 'text',
            size: 'small',
            fun: this.deleteHandle
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      },
      addOrUpdateVisible: false,
      workCenterTypeOptions: [],
      runTimeCodeDbTypeOptions: [],
      laborClassNoOptions: [],
      outsideOpItemOptions: []
    }
  },
  components: {
    ttable,
    TableForm
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  created() {
    this.getReportTypeDict()
    this.getRunTimeCodeDbTypeDict()
    this.getLaborClassNoCache()
    this.getOutsideOpItem()
  },
  methods: {
    // 获取数据列表
    getData() {
      if (this.$refs.operationTable !== undefined) {
        this.$refs.operationTable.getDataList()
      }
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.$router.push({
        name: 'operationForm',
        params: { id: row == null ? null : row.id }
      })
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认删除编号为' + row.operationNo, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning',
        closeOnClickModal: false
      })
        .then(function() {
          return delObj(row.id)
        })
        .then((response) => {
          var data = response.data
          if (data.code === 0) {
            this.$message.success('删除成功')
          } else {
            this.$message.error('删除失败')
          }
          this.getData()
        })
    },
    handleSelectionChange(val) {
      this.multipleSelection = val
    },
    getReportTypeDict() {
      remote('work_center_type').then((response) => {
        if (response.data.code === 0) {
          this.workCenterTypeOptions = response.data.data
          this.workCenterTypeOptions.forEach((item) => {
            item.label = '(' + item.value + ') ' + item.label
          })
        } else {
          this.workCenterTypeOptions = []
        }
      })
    },
    // 工作中心中文格式化
    formatWorkCenterType(row, column, cellValue) {
      this.workCenterTypeOptions.forEach((obj) => {
        if (obj.value === cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    getRunTimeCodeDbTypeDict() {
      remote('runtimecodedb_type').then((response) => {
        if (response.data.code === 0) {
          this.runTimeCodeDbTypeOptions = response.data.data
        } else {
          this.runTimeCodeDbTypeOptions = []
        }
      })
    },
    // 工作中心中文格式化
    formatRunTimeCodeDbType(row, column, cellValue) {
      this.runTimeCodeDbTypeOptions.forEach((obj) => {
        if (obj.value === cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    getLaborClassNoList() {
      return this.laborClassNoOptions
    },
    formatOutsideOpItem(row, column, cellValue) {
      this.outsideOpItemOptions.forEach((obj) => {
        if (obj.value === cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },

    // 格式化IFS库位
    formatLaborClassNo(row, column, cellValue) {
      this.laborClassNoOptions.forEach((obj) => {
        if (obj.value == cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    /**
     * 获取IFS人工类别字典并缓存
     */
    getLaborClassNoCache() {
      /* getLaborClassNo().then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.laborClassNoOptions = []
          if (_data.length > 0) {
            _data.forEach((item) => {
              const laborClassNoOption = {
                value: item.LC_NO,
                label: item.LC_NO
              }
              this.laborClassNoOptions.push(laborClassNoOption)
            })
          }
        }
      }) */
      remote('labor_class_type').then((response) => {
        if (response.data.code === 0) {
          this.laborClassNoOptions = response.data.data
        } else {
          this.laborClassNoOptions = []
        }
      })
    },
    getOutsideOpItem() {
      remote('out_side_type').then((response) => {
        if (response.data.code === 0) {
          this.outsideOpItemOptions = response.data.data
        } else {
          this.outsideOpItemOptions = []
        }
      })
    }
  }
}
</script>
